% Generated by roxygen2 (4.0.1): do not edit by hand
\docType{data}
\name{result_mcmc_newp}
\alias{result_mcmc_newp}
\title{Result of the mcmc using the nest database with anchored parameters}
\format{A list of class mcmcComposite with mcmc result for data(nest) with anchored parameters}
\usage{
result_mcmc_newp
}
\description{
Fit using the nest database with anchored parameters
}
\details{
Result of the mcmc using the nest database with anchored parameters
}
\examples{
\dontrun{
library(embryogrowth)
data(nest)
formated <- FormatNests(nest)
newp <- GenerateAnchor(nests=formated, number.anchors=7)
pfixed <- c(rK=2.093313)
resultNest_newp <- searchR(parameters=newp, fixed.parameters=pfixed,
  temperatures=formated, derivate=dydt.Gompertz, M0=1.7,
  test=c(Mean=39.33, SD=1.92), method = "BFGS", maxiter = 200)
data(resultNest_newp)
pMCMC <- embryogrowth_MHmcmc_p(resultNest_newp, accept=TRUE)
# Take care, it can be very long, sometimes several days
result_mcmc_newp <- embryogrowth_MHmcmc(result=resultNest_newp,
  parametersMCMC=pMCMC, n.iter=1000, n.chains = 1, n.adapt = 0,
	thin=1, trace=TRUE)
data(result_mcmc_newp)
data(resultNest_4p)
newp <- GenerateAnchor(nests=resultNest_4p, number.anchors=7)
# Here the confidence interval is built based on anchored parameters
plotR_hist(resultNest_4p, parameters=newp, SE=result_mcmc_newp$TimeSeriesSE,
 ylim=c(0,0.4), ylimH=c(0,0.4))
# Here the confidence interval is built based on parametric SSM equation
plotR_hist(resultNest_4p, SE=result_mcmc_4p$TimeSeriesSE,
 ylim=c(0,0.4), ylimH=c(0,0.4))
plot(result_mcmc_newp, las=1, xlim=c(0,30), parameters="294")
plot(result_mcmc_newp, las=1, xlim=c(0,30), parameters="296.333333333333")
plot(result_mcmc_newp, las=1, xlim=c(0,30), parameters=3)
}
}
\author{
Marc Girondot \email{marc.girondot@u-psud.fr}
}
\references{
Girondot, M. & Kaska, Y. Submitted. A model to predict
            temperature dependency on embryo growth rate and incubation
            duration from field data.
}
\keyword{datasets}

